@@ -13,7 +13,7 @@ use Exporter 'import';
 our @EXPORT_OK = @RxPerl::EXPORT_OK;
 our %EXPORT_TAGS = %RxPerl::EXPORT_TAGS;
 
-our $VERSION = "v0.28.2";
+our $VERSION = "v0.28.4";
 
 foreach my $func_name (@EXPORT_OK) {
     set_subname __PACKAGE__."::$func_name", \&{$func_name};
@@ -104,8 +104,7 @@ RxPerl::IOAsync - IO::Async adapter for RxPerl
 
 =head1 DESCRIPTION
 
-RxPerl::IOAsync is a module that lets you use the L<RxPerl> Reactive Extensions with your app that runs
-the IO::Async loop.
+RxPerl::IOAsync is a module that lets you use the L<RxPerl> Reactive Extensions in your app that uses IO::Async.
 
 =head1 DOCUMENTATION
 
